#
# spec file for package extra-cmake-modules
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _tar_path 5.45
# Full KF5 version (e.g. 5.33.0)
%{!?_kf5_version: %global _kf5_version %{version}}
# Last major and minor KF5 version (e.g. 5.33)
%{!?_kf5_bugfix_version: %global _kf5_bugfix_version %(echo %{_kf5_version} | awk -F. '{print $1"."$2}')}
%if 0%{?suse_version} >= 1330
%bcond_without doc
%else
%bcond_with doc
%endif
Name:           extra-cmake-modules
Version:        5.45.0
Release:        lp150.1.1
Summary:        CMake modules
License:        BSD-3-Clause
Group:          Development/Tools/Other
Url:            https://projects.kde.org/projects/kdesupport/extra-cmake-modules
Source:         http://download.kde.org/stable/frameworks/%{_tar_path}/%{name}-%{version}.tar.xz
# PATCH-FIX-OPENSUSE
Patch0:         bundle-lang.patch
BuildRequires:  cmake >= 3.0
BuildRequires:  gcc-c++
BuildRequires:  kf5-filesystem >= 5.6.0
Requires:       cmake >= 3.0
Requires:       gcc-c++
Requires:       kf5-filesystem
Recommends:     %{name}-doc
Provides:       kf5umbrella = 4.99.0
Obsoletes:      kf5umbrella < 4.99.0
%if %{with doc}
BuildRequires:  python3-Sphinx
%endif

%description
Extra modules and scripts for CMake.

For more information see http://community.kde.org/KDE_Core/Platform_11/Buildsystem/FindFilesSurvey

%package doc
Summary:        Documentation for extra-cmake-modules
Group:          Documentation/Other
BuildArch:      noarch
Requires:       %{name} = %{version}

%description doc
Extra modules and scripts for CMake.

For more information see http://community.kde.org/KDE_Core/Platform_11/Buildsystem/FindFilesSurvey
This package provides documentation for extra-cmake-modules

%prep
%setup -q
%patch0 -p1

%build
  %cmake_kf5 -d build
  %make_jobs

%install
  %kf5_makeinstall -C build

%files
%{_datadir}/ECM/

%if %{with doc}
%files doc
%doc %{_datadir}/doc/ECM/
%doc %lang(en) %{_mandir}/man7/ecm*.7*
%endif

%changelog
* Sat Apr 14 2018 lbeltrame@kde.org
- Update to 5.45.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.45.0.php
- Changes since 5.44.0:
  * Make use of upstream CMake infrastructure to detect the compiler toolchain
  * API dox: fix some "code-block" lines to have empty lines before/after
  * Add ECMSetupQtPluginMacroNames
  * Provide androiddeployqt with all prefix paths
  * Include the "stdcpp-path" in the json file
  * Resolve symlinks in QML import paths
  * Provide QML import paths to androiddeployqt
* Tue Mar 13 2018 lbeltrame@kde.org
- Update to 5.44.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.44.0.php
- Changes since 5.43.0:
  * Define __ANDROID_API__
  * Fix readelf command name on x86
  * Remove obsolete policy settings
  * Extend search path for NDK dependencies
  * Set ANDROID in the Android toolchain file
  * Fix include path for x86 targets
  * Android toolchain: add ANDROID_COMPILER_PREFIX variable.
* Tue Feb 13 2018 lbeltrame@kde.org
- Update to 5.43.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.43.0.php
- Changes since 5.42.0:
  * ecm_install_icons: refer to non-deprecated KDE_INSTALL_ICONDIR
  * FindQtWaylandScanner.cmake: Use qmake-query for HINT
  * Make sure to search for Qt5-based qmlplugindump
  * ECMToolchainAndroidTest doesn't exist anymore (kde#389519)
  * Don't set the LD_LIBRARY_PATH in prefix.sh
  * Add FindSeccomp to find-modules
  * Fall back to language name for translations lookup if locale name fails
  * Android: Add more includes
* Tue Jan 16 2018 lbeltrame@kde.org
- Update to 5.42.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.42.0.php
- Changes since 5.41.0:
  * Use readelf to find project dependencies
  * Introduce INSTALL_PREFIX_SCRIPT to easily set up prefixes
* Mon Jan  8 2018 tchvatal@suse.com
- Use python3 sphinx to generate the documentation module
* Sun Dec 17 2017 lbeltrame@kde.org
- Update to 5.41.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.41.0.php
- Changes since 5.40.0:
  * Add the description tag to the generated pkgconfig files
  * ecm_add_test: Use proper path sep on Windows
  * Fix variable name
  * restore old behaviour of FindPulseAudio
  * Remove FindSasl2.cmake from the ECM's attic.
  * Delete the .reviewboardrc file.
  * Add FindSasl2.cmake to ECM
  * Only pass the ARGS thing when doing Makefiles
  * Remove FindGLIB2.cmake and FindPulseAudio.cmake from attic
  * Add FindGLIB2.cmake and FindPulseAudio.cmake
  * ECMAddTests: set QT_PLUGIN_PATH so locally built plugins can be found
  * KDECMakeSettings: more docu about the layout of the build dir
* Mon Nov 13 2017 lbeltrame@kde.org
- Update to 5.40.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.40.0.php
- Changes since 5.39.0:
  * None
* Mon Oct 23 2017 lbeltrame@kde.org
- Update to 5.39.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.39.0.php
- Changes since 5.38.0:
  * Fix python bindings compilation after 7af93dd23873d0b9cdbac192949e7e5114940aa6
* Tue Sep 12 2017 lbeltrame@kde.org
- Update to 5.38.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.38.0.php
- Changes since 5.37.0:
  * Fix python bindings compilation after 7af93dd23873d0b9cdbac192949e7e5114940aa6
  * Forgot to add the test
  * Fix the fix
  * Fix build with older CMake versions.
  * Revert "RFC: Make ECMAddTests respect BUILD_TESTING"
  * Revert "doc: Add 'Since' note"
  * Set CMAKE_*_OUTPUT_DIRECTORY to run tests without installing.
  * Include a module for finding qml imports as runtime dependencies
  * doc: Add 'Since' note
  * RFC: Make ECMAddTests respect BUILD_TESTING
* Sat Aug 12 2017 christophe@krop.fr
- Update to 5.37.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.37.0.php
- Changes since 5.36.0 :
  * Add --gradle to androiddeployqt
  * Fix install apk target
  * Make ECMPoQmToolsTest actually fail if a translation is wrong
  * Fix usage of query_qmake: differ between calls expecting qmake or not
  * Add API dox for KDEInstallDirs' KDE_INSTALL_USE_QT_SYS_PATHS
  * KDECompilerSettings.cmake - handle Cywgin when setting LINK_FLAGS
  * Fix incomplete default path noted in QTQCHDIR documentation
  * Properly point at ECM
  * add a metainfo.yaml to make ECM a proper framework
  * Android: scan for qml files in the source dir, not in the install dir.
  * Stabilize ECMQtDeclareLoggingCategoryTest
* Thu Jul 13 2017 wbauer@tmo.at
- Add bundle-lang.patch to find .qm translations in
  /usr/share/locale-bundle/ (boo#1027925, boo#1048030)
* Wed Jul 12 2017 lbeltrame@kde.org
- Update to 5.36.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.36.0.php
- Changes since 5.35.0:
  * FindQHelpGenerator: avoid picking up Qt4 version
  * ECMAddQch: fail hard if needed tools are not present, to avoid surprises
  * Drop perl as dep for ecm_add_qch, not needed/used
  * (always include CheckCXXCompilerFlag before calling it)
  * guess less, test more
  * detect Xcode <= 6.2 from Clang version only
  * scan the whole install folder for qml dependencies
  * New: ECMAddQch, for generating qch & doxygen tag files
  * tests: improve error reporting for ECMAddAppIconTest
  * tests: fix output directory for KDEFetchTranslations
  * tests: fix last change on KDEFetchTranslations
  * tests: hopefully fix KDEFetchTranslations on Windows
  * Fix KDEInstallDirsTest.relative_or_absolute_usr, avoid Qt paths being used
* Sun Jun 11 2017 lbeltrame@kde.org
- Update to 5.35.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.35.0.php
- Changes since 5.34.0:
  * restore hidden-visibility testing with Xcode 6.2
  * ecm_qt_declare_logging_category(): more unique include guard for header
  * Drop modules from attic that are not useful anymore
  * Add or improve "Generated. Don't edit" messages and make consistent
  * Add a new FindGperf module
  * Change default pkgconfig install path for FreeBSD
* Mon May 15 2017 fabian@ritter-vogt.de
- Update to 5.34.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.34.0.php
- Changes since 5.33.0:
  * Fix test when compiling from a tarball
  * Sanitizers: Don't use GCC-like flags for e.g. MSVC
  * adapt to fetchpo changes and use vars for target directories to dry code
  * fix documentation, ecm_install_po_files_as_qm generates .qm, not .mo
  * use correct variable for fetch-translations injection
  * KDEPackageAppTemplates: improve API dox notation of function signature
  * KDEPackageAppTemplates: mark %%{dest} as deprecated
  * KDEPackageAppTemplates: fix note for %%{PROJECTDIRNAME}
  * KDEPackageAppTemplates: remove note of placeholder %%{src}, never supported
  * Fix minor CMake warning (CMP0054)
  * KDECompilerSettings: Pass -Wvla & -Wdate-time
  * Don't include tests together with modules
  * Allow test to work with older versions of qmlplugindump
  * Don't enable the test by default
  * Support older qmlplugindump versions
  * Introduce ecm_generate_qmltypes
  * Add a test for _repository_name() a function added for fetch-translations
  * Fix compilation under AppleClang (kde#377933)
  * Allow projects to include the file twice
  * Move the repository name recognition into a function
  * Fix rx that matches project names out of the git uri
  * Introduce fetch-translations build command
  * Use -Wno-gnu-zero-variadic-macro-arguments more
  * FindPyModGen: Also search for an unversioned clang++
- Remove patches, now upstream:
  * 0001-FindPyModGen-Also-search-for-an-unversioned-clang.patch
  * 0002-Import-Find-Clang-LLVM-from-KDevelop-for-Python-bind.patch
* Sat Apr 15 2017 lbeltrame@kde.org
- Update to 5.33.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.33.0.php
- Changes since 5.32.0:
  * KDE compiler settings: treat Clang and AppleClang equally
  * Improve error messages
  * Specify qml-root-path as the share directory in the prefix
  * default for ECM_ADDITIONAL_FIND_ROOT_PATH
  * Fix ecm_generate_pkgconfig_file compatibility with new cmake
  * Upgrade ECM version to 5.33.0.
  * Only register APPLE_* options if(APPLE)
* Tue Apr  4 2017 lbeltrame@kde.org
- Add upstream patches to fix Python binding generation:
  * 0001-FindPyModGen-Also-search-for-an-unversioned-clang.patch
  * 0002-Import-Find-Clang-LLVM-from-KDevelop-for-Python-bind.patch
* Sun Mar 19 2017 lbeltrame@kde.org
- Update to 5.32.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.32.0.php
- Changes since 5.31.0:
  * Detect inotify.
  * Upgrade ECM version to 5.32.0.
  * Revert "Automatically mark classes with pure virtual functions as /Abstract/."
* Thu Feb  9 2017 hrvoje.senjan@gmail.com
- Update to 5.31.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.31.0.php
* Mon Jan  9 2017 hrvoje.senjan@gmail.com
- Update to 5.30.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.30.0.php
* Sun Dec  4 2016 hrvoje.senjan@gmail.com
- Update to 5.29.0
  * Skip Python bindings test if PyQt isn't installed
  * Only add the test if python is found
  * Reduce the CMake minimum required
  * Add ecm_win_resolve_symlinks module
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.29.0.php
* Sat Nov  5 2016 hrvoje.senjan@gmail.com
- Update to 5.28.0
  * Make KDECMakeSettings work with KDE_INSTALL_DIRS_NO_DEPRECATED
  * Don't require the python bindings dependencies for ECM
  * Add the PythonModuleGeneration module
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.28.0.php
* Sun Oct  2 2016 hrvoje.senjan@gmail.com
- Update to 5.27.0
  * Make sure we don't add the appstream test twice
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.27.0.php
* Tue Sep  6 2016 hrvoje.senjan@gmail.com
- Update to 5.26.0
  * ecm_process_po_files_as_qm: Skip fuzzy translations
  * The default level for logging categories should be Info rather
    than Warning
  * Document ARGS variable in the create-apk-* targets
  * Create a test that validates projects' appstream information
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.26.0.php
* Sun Aug  7 2016 hrvoje.senjan@gmail.com
- Update to 5.25.0
  * Qt >= 5.5 is now required
  * Fix inclusion when there's no Qt5
  * Add a fallback method for query_qmake() when there's no
    Qt5 installation
  * Make sure ECMGeneratePriFile.cmake behaves like the rest of ECM
  * Appstream data changed its preferred location
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.25.0.php
* Wed Jul  6 2016 hrvoje.senjan@gmail.com
- Update to 5.24.0
  * Integrate relative library paths to APK
  * Use "/data" for DATAROOTDIR on Windows
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.24.0.php
* Mon Jun  6 2016 hrvoje.senjan@gmail.com
- Update to 5.23.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.23.0.php
* Sat May  7 2016 hrvoje.senjan@gmail.com
- Update to 5.22.0 (boo#980066)
  * Android deployment: support projects without things in share
    or lib/qml (kde#362578)
  * Enables KDE_INSTALL_USE_QT_SYS_PATHS if CMAKE_INSTALL_PREFIX
    Qt5 prefix
  * ecm_qt_declare_logging_category: improve error message when
    using without including
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.22.0.php
* Mon Apr  4 2016 hrvoje.senjan@gmail.com
- Update to 5.21.0 (boo#974793)
  * Fix _ecm_update_iconcache to only update the install location
  * Revert "ECMQtDeclareLoggingCategory: Include <QDebug> with the
    generated file"
  * Upgrade Qt version requirement to 5.4.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.21.0.php
* Sun Mar  6 2016 hrvoje.senjan@gmail.com
- Update to 5.20.0 (boo#970856)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.20.0.php
* Sat Feb  6 2016 hrvoje.senjan@gmail.com
- Update to 5.19.0 (boo#967668)
  * ECMAddAppIcon: Use absolute path when operating on icons
  * Make sure the prefix is looked-up on Android
  * Add a FindPoppler module
  * Use PATH_SUFFIXES in ecm_find_package_handle_library_components()
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.19.0.php
* Sat Jan  2 2016 hrvoje.senjan@gmail.com
- Update to 5.18.0
  * Make the KAppTemplate CMake module global
  * Silence CMP0063 warnings with KDECompilerSettings
  * ECMQtDeclareLoggingCategory: Include <QDebug> with the generated file
  * Fix CMP0054 warnings
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.18.0.php
* Fri Dec 11 2015 hrvoje.senjan@gmail.com
- Update to 5.17.0
  * Don't warn when SVG(Z) icons are provided with multiple
    sizes/level of detail
  * Make sure we load translations on the main thread. (kde#346188)
  * Overhaul the ECM build system.
  * Make it possible to enable Clazy on any KDE project
  * Do not find XCB's XINPUT library by default.
  * Clean export dir before generating an APK again
  * Use quickgit for Git repository URL.
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.17.0.php
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.16.0 (boo#955067)
  * Warn instead of error if ecm_install_icons finds no icons.
    (bug 354610)
  * Make it possible to build KDE Frameworks 5 with a plain qt 5.5.x
    installed from the normal qt.io installer on mac os
  * Do not unset cache variables in KDEInstallDirs. (kde#342717)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.16.0.php
* Mon Oct  5 2015 hrvoje.senjan@gmail.com
- Update to 5.15.0
  * Update GTK icon cache when installing icons.
  * Remove workaround to delay execution on Android
  * ECMEnableSanitizers: The undefined sanitizer is supported by gcc 4.9
  * Disable X11,XCB etc. detection on OS X
  * Look for the files in the installed prefix rather the prefix path
  * Use Qt5 to specify what's Qt5 installation prefix
  * Add definition ANDROID as needed in qsystemdetection.h.
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.15.0.php
* Tue Sep  8 2015 hrvoje.senjan@gmail.com
- Update to 5.14.0
  * Add macro to generate logging category declarations for Qt5.
  * ecm_generate_headers: Add COMMON_HEADER option and multiple
    header functionality
  * Add -pedantic for KF5 code (when using gcc or clang)
  * KDEFrameworkCompilerSettings: only enable strict iterators
    in debug mode
  * Also set the default visibility for C code to hidden.
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.14.0.php
* Tue Aug  4 2015 hrvoje.senjan@gmail.com
- Update to 5.13.0
  * The Qt version requirement has been bumped from 5.2 to 5.3
  * Debug output has been ported to categorized output, for less
    noise by default
  * Docbook documentation has been reviewed and updated
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.13.0.php
* Sun Jul  5 2015 hrvoje.senjan@gmail.com
- Update to 5.12.0
  * Improve error reporting of query_qmake macro
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.12.0.php
* Sun Jun  7 2015 hrvoje.senjan@gmail.com
- Update to 5.11.0
  * New arguments for ecm_add_tests(). (kde#345797)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.11.0.php
* Sun May  3 2015 hrvoje.senjan@gmail.com
- Update to 5.10.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.10.0.php
* Sat Apr  4 2015 hrvoje.senjan@gmail.com
- Update to 5.9.0
  * Extra CMake Modules (ECM) is now versioned like KDE Frameworks,
    therefore it is now 5.9, while it was 1.8 previously.
  * Allow configuration of SHARE_INSTALL_DIR, to handle multi-arch
    layouts better
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.9.0.php
* Sat Mar  7 2015 hrvoje.senjan@gmail.com
- Update to 5.8.0
  * Extend ecm_generate_headers macro to also support CamelCase.h headers
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.8.0.php
* Sun Feb  8 2015 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * KDEInstallDirs: warn about mixing relative and absolute
    installation paths on the command line
  * Added ECMAddAppIcon module to add icons to executable
    targets on Windows and Mac OS X
  * Fixed CMP0053 warning with CMake 3.1
  * Do not unset cache variables in KDEInstallDirs
  * New Android toolchain module
  * New ECMUninstallTarget module to create an uninstall target
  * Make KDECMakeSettings import ECMUninstallTarget by default
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.7.0.php
* Sun Jan 11 2015 hrvoje.senjan@gmail.com
- Update to 1.6.1
  * Fix building projects that use both GNUInstallDirs and
    KDEInstallDirs in different subdirectories by not unsetting
    cache variables in KDEInstallDirs.
  * Fix KDE_INSTALL_TARGETS_DEFAULT_ARGS value on OSX.
* Sat Jan  3 2015 hrvoje.senjan@gmail.com
- Update to 1.6.0
  * ECM's KDEInstallDirs now provides KDE_INSTALL_* variables.
    Both CMAKE_INSTALL_* variables and the older KDELibs4-compatible
    variables are provided, unless KDE_INSTALL_DIRS_NO_DEPRECATED
    is set to TRUE before the module is included. Even then, the
    CMAKE_INSTALL_* variables provided by the GNUInstallDirs module
    will still be set and understood (for compatibility with that
    module), unless KDE_INSTALL_DIRS_NO_CMAKE_VARIABLES
    is set to TRUE.
  * Add COMPATIBILITY argument to ecm_setup_version().
    Lots of libraries will want to use SameMajorVersion to make
    sure searching for version 1 of a library doesn't give you
    version 2, for example.
  * Fix ECMQueryQmake when Qt5Core is missing.
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.6.0.php
- BuildRequire 5.6.0 kf5-filesystem
* Sat Dec  6 2014 hrvoje.senjan@gmail.com
- Update to 1.5.0
  * Set CMAKE_INSTALL_SYSCONFDIR to /etc when CMAKE_INSTALL_PREFIX
    is /usr (instead of /usr/etc)
  * Enable -D_USE_MATH_DEFINES on Windows
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.5.0.php
* Sun Nov  2 2014 hrvoje.senjan@gmail.com
- Update to 1.4.0
  * New modules FindWaylandScanner and FindQtWaylandScanner,
    including macros ecm_add_qtwayland_client_protocol and
    ecm_add_qtwayland_server_protocol
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.4.0.php
- Don't build docs for SLE, python-Sphinx is not available there
* Sat Oct  4 2014 hrvoje.senjan@gmail.com
- Update to 1.3.0
  * New module ECMGeneratePkgConfigFile, for frameworks to
    install a pkgconfig file.
  * New option ECM_ENABLE_SANITIZERS, to enable clang sanitizers.
    Example: ECM_ENABLE_SANITIZERS='address;undefined'
  * New option BUILD_COVERAGE, to enable code coverage.
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.3.0.php
* Tue Sep  9 2014 hrvoje.senjan@gmail.com
- Update to 1.2.0
  * For more details please see:
    http://kde.org/announcements/kde-frameworks-5.2.php
- Drop 0001-Remove-Qt5-debugfull-hack-from-ECMConfig.cmake.patch,
  merged upstream
* Sat Aug  2 2014 hrvoje.senjan@gmail.com
- Update to 1.1.0
  * For more details please see:
    http://www.kde.org/announcements/kde-frameworks-5.1.php
- Add Source URL
- Added 0001-Remove-Qt5-debugfull-hack-from-ECMConfig.cmake.patch from
  upstream
- Per patch, pkgconfig(Qt5Core) >= 5.2.0 for gcc-c++ Requires
* Tue Jul  1 2014 hrvoje.senjan@gmail.com
- Update to 1.0.0
  * Final release of KDE Frameworks 5
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/kde-frameworks-5.0.php
* Sun Jun  1 2014 hrvoje.senjan@gmail.com
- Update to 0.0.14
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta3.php
- Make only doc subpackage noarch; due to changes since 0.0.13, e-c-m
  can no longer be packaged as noarch
- Drop libqt5-linguist-devel Requires
* Sun May  4 2014 hrvoje.senjan@gmail.com
- Update to 0.0.13
  * Further buildsystem improvements
- Added python-Sphinx BuildRequires to build docs
- Provide doc subpackage
- Added kf5-filesystem >= 4.99.0 and libqt5-linguist-devel >= 5.2.0
  Requires
- Obsolete and provide kf5umbrella (e-c-m now provides KF5Config)
* Tue Apr 22 2014 hrvoje.senjan@gmail.com
- Added pkgconfig(Qt5Core) to e-c-m Requires, every user of the
  package always needs it
* Sat Mar 29 2014 hrvoje.senjan@gmail.com
- Update to 0.0.12
  * Buildsystem improvements
* Wed Mar  5 2014 hrvoje.senjan@gmail.com
- Update to 0.0.11
  * Buildsystem cleanups
  * Added FindEGL, FindSharedMimeInfo and FindWayland modules
* Sat Feb  8 2014 hrvoje.senjan@gmail.com
- Init extra-cmake-modules package
